#!/bin/bash
#
# diags - Admin Diagnostics script
#
# Type  : Utility
#
# Author: Rob Allen
#
# Date  : 29.04.2008
#
# Program Description
# ===================
#
# Amendment History
# =================
# 02.03.09 Script written (RA)
# 27.10.09 Updated script to used new SMTP option in pinsafe.conf (RA)
# 18.11.09 Added NSLookup, and ping to diagnostics menu (RA)
# "0.2"
# 18.03.10 Added validity checking to user inputs (RA)
# 18.03.10 Added netstat, trace route, and nics to menu (RA)

# 0.3
# 27.07.10 Added use of nmap, to detect SMTP server, before using email (RA)
# 0.4
# 24.01.12 Added PERC H200 (SAS2008) raid status support (RB)
#

# DEBUG=/backups/robi
PINSAFE_TYPE="$1"
LOCK=/var/lock/subsys
AUDIT_LOG=/var/log/cmi/audit.log
TOMCAT=/usr/local/tomcat
WEBINF=$TOMCAT/webapps/pinsafe/WEB-INF
TOMCAT_CONF=$TOMCAT/conf/server.xml
NETWORKS=$BACKUPROOT/networking
SWIVEL=/home/swivel/.swivel
UPLOAD=/backups/upload
SMTP_SERVER=`grep ^SMTP /etc/pinsafe.conf|cut -d\= -f2`
version="0.5"
COPYRIGHT_YEAR="2012"

inv=`tput smso`
nor=`tput rmso`
t_err=n; m_err=n; h_err=n; mon_err=n

heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 if test $DR; then
  if test $DR = "yes"; then
   clear
   echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                                  ${inv}DR${nor}"; fi
 fi
 echo 
 echo $1
 echo
}

s_heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 if test $DR; then
  if test $DR = "yes"; then
   clear
   echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                                  ${inv}DR${nor}"; fi
 fi
 echo
}

audit() {
 audit_date=`date "+%d%m%y %T"`
 echo "$audit_date : $1" >> $AUDIT_LOG
}

yorn() {
 echo
 read -p "Are you sure? (Yes/No): " yn
 check_ans $1 $yn
}

check_ans() {
 if test ! $2; then
  $1; fi 
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y"; then
  $1; fi
}

diags_menu() {
 heading "Appliance Diagnostics"
 if test -d /etc/vmware-tools; then
  echo "1. Support logs and information"
  echo "2. VMWare Tools"
  echo "3. NSLookup"
  echo "4. Ping an IP"
  echo "5. Telnet port test"
  echo "6. Routing table"
  echo "7. Network Interfaces"
  echo "8. Trace Route"
  echo "0. $ret_menu_desc"
  echo
  read -p "Select: " option
  case $option in
   1) support_info; diags_menu; ;;
   2) vmware_tools; diags_menu; ;;
   3) nslookup_test; diags_menu; ;;
   4) ping_test; diags_menu; ;;
   5) telnet_port; diags_menu; ;;
   6) routing_table; diags_menu; ;;
   7) nics; diags_menu; ;;
   8) trace_route; diags_menu; ;;
   *) exit; ;;
  esac
 else
  echo "1. Support logs and information"
  echo "2. RAID Status"
  echo "3. NSLookup"
  echo "4. Ping an IP"
  echo "5. Telnet port test"
  echo "0. $ret_menu_desc"
  echo
  read -p "Select: " option
  case $option in
   1) support_info; diags_menu; ;;
   2) raid_opt $RAIDtype; diags_menu; ;;
   3) nslookup_test; diags_menu; ;;
   4) ping_test; diags_menu; ;;
   5) telnet_port; diags_menu; ;;
   *) exit; ;;
  esac
 fi
}

validate() {
 if ! test $1; then
  echo
  read -p "No value entered" yn
  diags_menu; fi
}

trace_route() {
 heading "Trace IP Route"
 read -p "IP Address: " trace_ip
 validate $trace_ip
 traceroute $trace_ip
 echo; read -p "Press Return to Continue" yn
}

nics() {
 heading "Check Network Interfaces"
 ip a
 echo; read -p "Press Return to Continue" yn
}

routing_table() {
 heading "Check Routing Table"
 netstat -nr
 echo; read -p "Press Return to Continue" yn
}

nslookup_test() {
 heading "Check DNS resolving using NSlookup"
 read -p "Domain Name: " domain_name
 validate $domain_name
 yorn diags_menu
 nslookup $domain_name
 echo; read -p "Press Return to Continue" yn
}

ping_test() {
 heading "Check Network IP"
 read -p "Host name or IP: " ping_dest
 validate $ping_dest
 echo
 ping -c5 $ping_dest
 echo; read -p "Press Return to Continue" yn
}

telnet_port() {
 heading "Test ports using Telnet"
 read -p "Service IP: " serv_ip
 read -p "Service Port: " serv_port
 validate $serv_ip
 validate $serv_port
 echo
 telnet $serv_ip $serv_port
 echo; read -p "Press Return to Continue" yn
}

vmware_tools() {
 heading "VMWare Tools"
 vmstat
 echo
 echo "Memory"
 echo "     swpd: the amount of virtual memory used."
 echo "     free: the amount of idle memory."
 echo "     buff: the amount of memory used as buffers."
 echo "     cache: the amount of memory used as cache."
 echo
 echo "CPU"
 echo "     These are percentages of total CPU time spent:"
 echo "     us: Running non-kernel code. (user time, including nice time)"
 echo "     sy: Running kernel code. (system time)"
 echo "     id: Idle time."
 echo "     wa: Waiting for IO."

 echo; read -p "Press Return to Continue" yn
}

support_info() {
 heading "Support Information"
 echo "Gathering support files, and creating a zip archive."
 echo; echo "Please enter an email address to send the support archive to."
 echo
 read -p "Email: " DEST
 if test $SMTP_SERVER; then
  read -p "SMTP server ($SMTP_SERVER): " SMTP
  if test ! $SMTP; then
   SMTP=SMTP_SERVER; fi
 else
  read -p "SMTP server: " SMTP
 fi 
 FROM="PINsafe"
 zip_files

 if test $DEST && test $SMTP; then
  cd $UPLOAD
  nmap -P0 -n -p 25 $SMTP | grep open > /dev/null
  if test $? = 0; then
   email -b -s "PINsafe support archive" -a $FNAME -n $FROM -f $FROM $DEST -r $SMTP
  else
   echo; echo "The SMTP server $SMTP is not available"
  fi
 fi

 echo; echo "The support log file may be download using SFTP from /backups/upload"
 echo; read -p "Press Return to Continue" yn
}

zip_files() {
 LOG=$UPLOAD/logs
 FNAME=support_info.tar.gz
 mkdir -p $LOG/pinsafe
 mkdir -p $LOG/pinsafe_logs
 mkdir -p $LOG/swivel
 mkdir -p $LOG/tomcat
 mkdir -p $LOG/CMI
 mkdir -p $LOG/Appliance
 cp $WEBINF/logs/* $LOG/pinsafe_logs
 tail -900 /var/log/tomcat/catalina.out > $LOG/tomcat/catalina.out
 cp /var/log/cmi/* $LOG/CMI
 cp /var/log/swivel/* $LOG/swivel
 version_opt exit > $LOG/version_info.txt
 cp $SWIVEL/conf/config.xml $LOG/pinsafe
 cp $SWIVEL/conf/ranges.xml $LOG/pinsafe
 cp $SWIVEL/data/repository.xml $LOG/pinsafe
 cp /etc/pinsafe.conf $LOG/pinsafe
 date > $LOG/date.txt
 ip a > $LOG/Appliance/network.txt
 netstat -nr >> $LOG/Appliance/network.txt
 uptime > $LOG/Appliance/uptime.txt
 df -h > $LOG/Appliance/disk_space.txt
 ps -eaf > $LOG/Appliance/process_listing.txt
 cat /proc/meminfo > $LOG/Appliance/Memory.txt
 if test -f /proc/drbd; then
  cat /proc/drbd > $LOG/Appliance/drbd.txt; fi
 cp /var/log/messages $LOG/Appliance
 rm -f $UPLOAD/support_info.tar.gz
 cd $UPLOAD
 tar cfz $FNAME logs > /dev/null 2>&1
 rm -r -f $LOG
}

version_opt() {
 smenu_vers=`grep ^version= /usr/local/bin/smenu|cut -d\" -f2`
 backup_vers=`grep ^version= /usr/local/bin/backup.sh|cut -d\" -f2`
 restore_vers=`grep ^version= /usr/local/bin/restore.sh|cut -d\" -f2`
 cert_vers=`grep ^version= /usr/local/bin/cert_manage.sh|cut -d\" -f2`
 diags_vers=`grep ^version= /usr/local/bin/diags.sh|cut -d\" -f2`
 echo "CMI             : $smenu_vers"
 echo "CMI Backup      : $backup_vers"
 echo "CMI Restore     : $restore_vers"
 echo "CMI Certs.      : $cert_vers"
 echo "CMI Diags.      : $diags_vers"
 echo "Appliance Build : $APPLIANCE_VER"
 if test -f $WEBINF/conf/interface.xml; then
  pin_build=`grep version\> $WEBINF/conf/interface.xml | cut -d\> -f2|cut -d\& -f1 | cut -dv  -f2`
  echo "Swivel Version  : $pin_build"
 fi
 tom_build=`ls /usr/local|grep apache|cut -d\- -f3`
 echo "Tomcat Version  : $tom_build"
 java_build=`ls /usr/java|grep jre|cut -d\e -f2`
 echo "Java Version    : $java_build"
 if test "$APPLIANCE_TYPE" = "AA" || test $DR = "yes"; then
  mysql_build=`mysql --version|cut -d\  -f6|cut -d\, -f1`
  echo "MySQL Version   : $mysql_build"; fi
 webmin_build=`cat /etc/webmin/version`
 echo "Webmin Version  : $webmin_build"
 if test -x /usr/bin/vmware-toolbox-cmd; then
    VMware_tools_ver=`vmware-toolbox-cmd -v`
    echo "VMware Tools    : $VMware_tools_ver"
 fi
 if test `dmidecode | grep -c Dell` -gt 0; then
  Delltag=`dmidecode |grep -i "serial number"|head -1|cut -d\: -f2`
  DellSerial=`dmidecode | grep -i "serial number" | grep "\.\."|cut -d\. -f3`
  echo "Dell Tag        :$Delltag"
  echo "Dell Serial     : $DellSerial"
 fi
}

raid_type(){
 if `lspci|grep -i 3ware > /dev/null`; then
  RAIDtype="3ware"
 elif `lspci|grep -i SAS2008 > /dev/null`; then
  RAIDtype="SAS2008"
 elif `lspci|grep -i mpt > /dev/null`; then
  RAIDtype="mpt"
 elif `lspci|grep -i MegaRAID > /dev/null`; then
  RAIDtype="MegaRAID"
 else
  RAIDtype="none"
 fi
}

raid_opt(){
 heading "RAID Status"
 if test $1 = "3ware"; then
  tw_cli /c0 show
 elif test $1 = "SAS2008"; then
  sas2ircu 0 STATUS
 elif test $1 = "mpt"; then
  mpt-status
 elif test $1 = "MegaRAID"; then
  /opt/MegaRAID/MegaCli/MegaCli -LDInfo -LALL -aAll
 elif test $1 = "none"; then
  echo "RAID status is not available"
 fi
 echo; read -p "Press Return to Continue" yn
}

return_point() {
 if test $1 = "ip_opt"; then
  ret_menu_desc="IPs & Routing"; fi
 if test $1 = "adv_menu"; then
  ret_menu_desc="Advanced Menu"; fi
 if test $1 = "dns_serv"; then
  ret_menu_desc="DNS Servers"; fi
 if test $1 = "nic_speed"; then
  ret_menu_desc="Change NIC Speeds / Negotiation"; fi
}

raid_type
return_point $2
diags_menu
