#!/bin/bash
# install - Install script
#
# Type  : Utility
#
# Author: Rob Allen
#
# Date  : 19.08.2008
#
# Program Description
# ===================
# Script to control Swivel Appliance.
# Supported services, Tomcat, MySQL, Heartbeat, Mon, and Backups
#
#
# Amendment History
# =================
# 09.03.08 Created today (RA)
# 01.04.08 Update host_mysql_slave & host_mysql_master to use LocalhostIP
#          variable and not localhost command (RA)
#
# 25.01.12 updated the copyright year as requested by Chris. (RB)
#
#
# stty intr undef
# stty intr 

inv=`tput smso`
nor=`tput rmso`
LOCK=/var/lock/subsys
COPYRIGHT_YEAR="2012"

env_validate() {
 mkdir -p /backups/iso
 mkdir -p /backups/config
 mkdir -p /backups/restore
 mkdir -p /backups/.iso-scratch
 mkdir -p /var/log/cmi
 mkdir -p /backups/.default
#backup.sh
#restore.sh
}

pinsafe_conf() {
 if test ! -f /etc/pinsafe.conf; then
  clear
  echo "pinsafe.conf is missing"
  echo "Auto populating file"
  echo "archives=30" >> /etc/pinsafe.conf
  echo "logs=30" >> /etc/pinsafe.conf
  echo "TMOUT=30" >> /etc/pinsafe.conf
 fi
}

appliance_type() {
 if test ! `grep PINSAFE_TYPE /etc/pinsafe.conf`; then
  echo "PINSAFE_TYPE is missing..."
  echo "Please select the Appliance type:"
  echo "1. Primary"
  echo "2. Secondary"
  echo "3. Standalone"
  echo "0. Exit"
  echo; echo -n "Select: "
  read ans
  case $ans in
   1) echo "PINSAFE_TYPE=Primary" >> /etc/pinsafe.conf; ;;
   2) echo "PINSAFE_TYPE=Standby" >> /etc/pinsafe.conf; ;;
   3) echo "PINSAFE_TYPE=Single " >> /etc/pinsafe.conf; ;;
   *) echo "Exiting"; exit; ;;
  esac
 fi

 if test ! `grep APPLIANCE_VERS /etc/pinsafe.conf`; then
  echo "APPLIANCE_VERS=Pre_V2" >> /etc/pinsafe.conf; fi

 if test ! `grep DR /etc/pinsafe.conf`; then
  echo "DR=no" >> /etc/pinsafe.conf; fi

 if test ! `grep ActiveIP /etc/pinsafe.conf`; then
  echo "ActiveIP=0.0.0.0" >> /etc/pinsafe.conf; fi

 if test `grep "PINSAFE_TYPE=Single" /etc/pinsafe.conf`; then
  if test ! `grep "PINSAFE_TYPE=Single " /etc/pinsafe.conf`; then
   sed -i "s/Single/Single /g" /etc/pinsafe.conf; fi
 fi
}

duff() {
 if test -f /etc/ha.d/haresources; then
  if test `grep drbd /etc/ha.d/haresources |grep \#|cut -d\  -f1`; then
   APPLIANCE_TYPE="AA"
  else
   APPLIANCE_TYPE="AP"; fi
 else
  APPLIANCE_TYPE="SA"
 fi

 if test ! $PINSAFE_TYPE; then
  stnd_err "Appliance type is not correctly configured."; fi
}

heading() {
 clear
 if test $DR = "yes"; then
  echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                                  ${inv}DR${nor}"
 else
  echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 fi
 echo
 echo $1
 echo
}

s_heading() {
 clear
 if test $DR = "yes"; then
  echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor} : $1                                      ${inv}DR${nor}"
 else
  echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor} : $1                                ${inv}$PINSAFE_TYPE${nor}"
 fi
 echo
}

check_running() {
 if test -f $LOCK/$1; then
  value="Running"
 else
  value="Stopped"; fi
}

audit() {
 audit_date=`date "+%d%m%y %T"`
 echo "$audit_date : $1" >> $AUDIT_LOG
}

pinsafe_conf
appliance_type
